@@ -1,9 +1,7 @@
 from compas.datastructures import Network
-
 from compas.geometry import length_vector
 
-from compas_cem import Data
-
+from compas_cem.data import Data
 from compas_cem.diagrams import NodeMixins
 from compas_cem.diagrams import EdgeMixins
 
@@ -16,7 +14,7 @@ __all__ = ["Diagram"]
 # ==============================================================================
 
 
-class Diagram(NodeMixins, EdgeMixins, Network, Data):
+class Diagram(Data, NodeMixins, EdgeMixins, Network):
     """
     Base class that shares functionality across diagrams.
     """
@@ -252,6 +250,11 @@ class Diagram(NodeMixins, EdgeMixins, Network, Data):
                 self.number_of_loaded_nodes()]
         return tpl.format(*data)
 
+    def __str__(self):
+        """
+        """
+        return self.__repr__()
+
 # ==============================================================================
 # Main
 # ==============================================================================
