@@ -9,7 +9,10 @@ from compas_rhino.geometry import RhinoPoint
 
 class SearchNodeKeyComponent(component):
     def RunScript(self, diagram, point):
-        if point and diagram:
-            pt = RhinoPoint.from_geometry(point).to_compas()
-            gkey = geometric_key(pt, diagram.tol)
-            return diagram.gkey_node[gkey]
+        if not (point and diagram):
+            return
+
+        pt = RhinoPoint.from_geometry(point).to_compas()
+        gkey = geometric_key(pt, diagram.tol)
+
+        return diagram.gkey_node[gkey]
